Index: trunk/psLib/src/astronomy/psCoord.h
===================================================================
--- trunk/psLib/src/astronomy/psCoord.h	(revision 3264)
+++ trunk/psLib/src/astronomy/psCoord.h	(revision 3334)
@@ -10,6 +10,6 @@
 *  @author GLG, MHPCC
 *
-*  @version $Revision: 1.26 $ $Name: not supported by cvs2svn $
-*  @date $Date: 2005-02-17 19:26:23 $
+*  @version $Revision: 1.27 $ $Name: not supported by cvs2svn $
+*  @date $Date: 2005-02-25 22:29:19 $
 *
 *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -292,15 +292,15 @@
 );
 
 /** Creates the appropriate transform for converting from ICRS to Galatic
  *  coordinate systems.
  *
  */
-psSphereTransform* psSphereTransformICRSToGalatic(void);
-
-/** Creates the appropriate transform for converting from Galatic to ICRS
+psSphereTransform* psSphereTransformICRSToGalactic(void);
+
+/** Creates the appropriate transform for converting from Galactic to ICRS
  *  coordinate systems.
  *
  */
-psSphereTransform* psSphereTransformGalaticToICRS(void);
+psSphereTransform* psSphereTransformGalacticToICRS(void);
 
 /** Allocates memory for a psProjection structure
@@ -292,15 +292,15 @@
 );
 
-/** Creates the appropriate transform for converting from ICRS to Galatic
+/** Creates the appropriate transform for converting from ICRS to Galactic
  *  coordinate systems.
  *
